Dialect

Enum Dialect 

pub enum Dialect {
Show 30 variants Ansi, Athena, BigQuery, ClickHouse, Databricks, DuckDb, Hive, Mysql, Oracle, Postgres, Presto, Redshift, Snowflake, Spark, Sqlite, StarRocks, Trino, Tsql, Doris, Dremio, Drill, Druid, Exasol, Fabric, Materialize, Prql, RisingWave, SingleStore, Tableau, Teradata,
}
Supported SQL dialects.

Mirrors the full set of dialects supported by Python’s sqlglot library. Dialects are grouped into Official (core, higher-priority maintenance) and Community (contributed, fully functional) tiers.

Variants



Ansi

ANSI SQL standard (default / base dialect)



Athena

AWS Athena (Presto-based)



BigQuery

Google BigQuery



ClickHouse

ClickHouse



Databricks

Databricks (Spark-based)



DuckDb

DuckDB



Hive

Apache Hive



Mysql

MySQL



Oracle

Oracle Database



Postgres

PostgreSQL



Presto

Presto



Redshift

Amazon Redshift (Postgres-based)



Snowflake

Snowflake



Spark

Apache Spark SQL



Sqlite

SQLite



StarRocks

StarRocks (MySQL-compatible)



Trino

Trino (Presto successor)



Tsql

Microsoft SQL Server (T-SQL)



Doris

Apache Doris (MySQL-compatible)



Dremio

Dremio



Drill

Apache Drill



Druid

Apache Druid



Exasol

Exasol



Fabric

Microsoft Fabric (T-SQL variant)



Materialize

Materialize (Postgres-compatible)



Prql

PRQL (Pipelined Relational Query Language)



RisingWave

RisingWave (Postgres-compatible)



SingleStore

SingleStore (MySQL-compatible)



Tableau

Tableau



Teradata

Teradata

Implementations

Source

impl Dialect

pub fn support_level(&self) -> &'static str

Returns the support tier for this dialect.

pub fn all() -> &'static [Dialect]

Returns all dialect variants.

pub fn from_str(s: &str) -> Option<Dialect>

Parse a dialect name (case-insensitive) into a Dialect.