Structs
- Dialect
Registry - Thread-safe registry for custom dialect plugins.
Enums
- Dialect
Ref - A reference to either a built-in
Dialector a custom dialect registered via the plugin system.
Traits
- Dialect
Plugin - Trait that external code can implement to define a custom SQL dialect.
Functions
- register_
dialect - Register a custom dialect plugin in the global registry.
- resolve_
dialect - Look up a dialect by name, returning either a built-in or custom
DialectRef. - transform
- Transform a statement from one dialect to another, supporting custom dialect plugins.
- transpile_
ext - Transpile a SQL string using
DialectRef, supporting custom plugins. - transpile_
statements_ ext - Transpile multiple statements using
DialectRef, supporting custom plugins.