pub fn register_dialect<P: DialectPlugin + 'static>(plugin: P)Expand description
Register a custom dialect plugin in the global registry.
This is a convenience wrapper around [DialectRegistry::global().register()].
pub fn register_dialect<P: DialectPlugin + 'static>(plugin: P)Register a custom dialect plugin in the global registry.
This is a convenience wrapper around [DialectRegistry::global().register()].