pub enum ChangeAction {
Remove(AstNode),
Insert(AstNode),
Keep(AstNode, AstNode),
Move(AstNode, AstNode),
Update(AstNode, AstNode),
}Expand description
A change action describing a single difference between two ASTs.
Variants
Remove(AstNode)
A node present in source that was removed.
Insert(AstNode)
A node inserted into target that was not in source.
Keep(AstNode, AstNode)
A node that is structurally identical in both trees.
Move(AstNode, AstNode)
A node that was moved to a different position in the tree.
Update(AstNode, AstNode)
A node in source that was replaced by a different node in target.