pub type Result<T> = Result<T, SqlglotError>;Expand description
Convenience alias for results that can fail with SqlglotError.
Aliased Type
pub enum Result<T> {
Ok(T),
Err(SqlglotError),
}pub type Result<T> = Result<T, SqlglotError>;Convenience alias for results that can fail with SqlglotError.
pub enum Result<T> {
Ok(T),
Err(SqlglotError),
}